==> nextcloud-25.0.8.tgz: nextcloud/apps/user_status/l10n/zh_HK.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "最近的狀態",
    "In a meeting" : "會議中",
    "Commuting" : "通勤中",
    "Out sick" : "生病了 ",
    "Vacationing" : "休假中",
    "Working remotely" : "遠程工作中",
    "In a call" : "通話中",
    "User status" : "用戶狀態",
    "View profile" : "查看個人資料",
    "Clear status after" : "繼此之後清空狀態",
    "Emoji for your status message" : "狀態訊息的表情符號",
    "What is your status?" : "您目前的狀態是什麼呢？",
    "Predefined statuses" : "預先定義的狀態",
    "Previously set" : "先前設定",
    "Reset status" : "重設狀態",
    "Set status" : "設定狀態",
    "Online status" : "線上狀態",
    "Status message" : "狀態訊息",
    "Your status was set automatically" : "您的狀態是自動設置的",
    "Clear status message" : "清空狀態訊息",
    "Set status message" : "設定狀態訊息",
    "Reset status to \"{icon} {message}\"" : "將狀態重置為 “{icon} {message}”",
    "Reset status to \"{message}\"" : "將狀態重置為“{message}”",
    "Reset status to \"{icon}\"" : "將狀態重置為“{icon}”",
    "There was an error saving the status" : "儲存狀態時發生錯誤",
    "There was an error clearing the status" : "變更狀態時發生錯誤",
    "There was an error reverting the status" : "恢復狀態時出錯",
    "No recent status changes" : "最近沒有狀態變更",
    "Away" : "離開",
    "Do not disturb" : "請勿打擾",
    "{status}, {timestamp}" : "{status}，{timestamp}",
    "Don't clear" : "不要清空",
    "Today" : "今日",
    "This week" : "本星期",
    "Online" : "在線",
    "Invisible" : "隱藏",
    "Offline" : "離線",
    "There was an error saving the new status" : "儲存新狀態時發生錯誤",
    "30 minutes" : "30分鐘",
    "1 hour" : "1 小時",
    "4 hours" : "4 小時",
    "Mute all notifications" : "靜音所有通知",
    "Appear offline" : "顯示為離線"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/user_status/l10n/zh_HK.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "最近的狀態",
    "No recent status changes" : "最近沒有狀態變更",
    "In a meeting" : "會議中",
    "Commuting" : "通勤中",
    "Out sick" : "生病了 ",
    "Vacationing" : "休假中",
    "Working remotely" : "遠程工作中",
    "In a call" : "通話中",
    "User status" : "用戶狀態",
    "View profile" : "查看個人資料",
    "Clear status after" : "繼此之後清空狀態",
    "Emoji for your status message" : "狀態訊息的表情符號",
    "What is your status?" : "您目前的狀態是什麼呢？",
    "Predefined statuses" : "預先定義的狀態",
    "Previously set" : "先前設定",
    "Reset status" : "重設狀態",
    "Set status" : "設定狀態",
    "Online status" : "線上狀態",
    "Status message" : "狀態訊息",
    "Your status was set automatically" : "您的狀態是自動設置的",
    "Clear status message" : "清空狀態訊息",
    "Set status message" : "設定狀態訊息",
    "Reset status to \"{icon} {message}\"" : "將狀態重置為 “{icon} {message}”",
    "Reset status to \"{message}\"" : "將狀態重置為“{message}”",
    "Reset status to \"{icon}\"" : "將狀態重置為“{icon}”",
    "There was an error saving the status" : "儲存狀態時發生錯誤",
    "There was an error clearing the status" : "變更狀態時發生錯誤",
    "There was an error reverting the status" : "恢復狀態時出錯",
    "Don't clear" : "不要清空",
    "Today" : "今日",
    "This week" : "本星期",
    "Online" : "在線",
    "Away" : "離開",
    "Do not disturb" : "請勿打擾",
    "Invisible" : "隱藏",
    "Offline" : "離線",
    "There was an error saving the new status" : "儲存新狀態時發生錯誤",
    "30 minutes" : "30分鐘",
    "1 hour" : "1 小時",
    "4 hours" : "4 小時",
    "Mute all notifications" : "靜音所有通知",
    "Appear offline" : "顯示為離線",
    "{status}, {timestamp}" : "{status}，{timestamp}"
},
"nplurals=1; plural=0;");
